# nonebot-plugin-heweather

获取和风天气信息并转换为图片

# 配置

## apikey

注意保留 `&key=`

```
QWEATHER_APIKEY = &key=xxx
```

## 字体文件

在`resource`里

```
QWEATHER_FONT = "./data/msyh.ttf'
```

- 使用 truetype 字体
- 建议使用微软雅黑

## 图标文件

在`resource`里

```
QWEATHER_ICON_DIR = "./data/icon'
```

- [下载地址](https://dev.qweather.com/docs/start/icons/)
